@@ -1,5 +1,5 @@
 /*------------------------------------------------------
- Maximum likelihood estimation 
+ Bayesian Maximum likelihood estimation 
  of migration rate  and effectice population size
  using a Metropolis-Hastings Monte Carlo algorithm                            
  -------------------------------------------------------                        
@@ -7,22 +7,31 @@
  
  creates data structures,
  read data (Electrophoretic loci, sequences, microsats),
- feeds data into tree (?),
  prints data,
  destroys data.
+
+Copyright 1997-2002 Peter Beerli and Joseph Felsenstein 
+Copyright 2003-2008 Peter Beerli
+Copyright 2009-2012 Peter Beerli and Michal Palczewski
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
+of the Software, and to permit persons to whom the Software is furnished to do
+so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all copies
+or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
+INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
+PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
+OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
- Peter Beerli 1996, Seattle
- beerli@fsu.edu
- 
-Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
-Copyright 2003-2007 Peter Beerli, Tallahassee FL
- 
- This software is distributed free of charge for non-commercial use
- and is copyrighted. Of course, we do not guarantee that the software
- works and are not responsible for any damage you may cause or have.
- 
- 
-$Id: data.c 2032 2012-05-11 15:09:38Z beerli $
+$Id: data.c 2067 2012-07-27 20:59:32Z beerli $
 
 -----------------------------------
 add this to the microsatellite data, this will allow to use
@@ -494,17 +503,17 @@ init_data_structure1 (data_fmt ** data, option_fmt * options)
         (*data)->seq[0]->sites = (long *) mycalloc (loci, sizeof (long));
         (*data)->seq[0]->links = (boolean *) mycalloc (loci, sizeof (boolean));
         (*data)->position = (long *) mycalloc (loci, sizeof (long));
-	(*data)->datatype = (long *) mycalloc(loci, sizeof(long));
+	(*data)->datatype = (char *) mycalloc(loci, sizeof(char));
 	(*data)->numdatatypealloc = loci;
 	(*data)->numsublocialloc = loci;
 	(*data)->subloci = (long *) mycalloc(loci,sizeof(long));
-	(*data)->numrepeatnumbers = (long *) calloc(loci, sizeof(long));
-	(*data)->repeatnumbers = (long **) calloc(loci, sizeof(long *));
-	(*data)->repeatlength = (long *) calloc(loci, sizeof(long));
+	(*data)->numrepeatnumbers = (long *) mycalloc(loci, sizeof(long));
+	(*data)->repeatnumbers = (long **) mycalloc(loci, sizeof(long *));
+	(*data)->repeatlength = (long *) mycalloc(loci, sizeof(long));
 	for(locus=0;locus<loci;locus++)
 	  {
 	    (*data)->numrepeatnumbers[locus] = 1;
-	    (*data)->repeatnumbers[locus] = (long *) calloc(1, sizeof(long));
+	    (*data)->repeatnumbers[locus] = (long *) mycalloc(1, sizeof(long));
 	  }
     }
     else
@@ -1491,7 +1500,7 @@ read_hapmap_genotypes (FILE * infile, data_fmt * data, option_fmt * options, lon
 	    data->numalleles[pop][locus] = data->numind[pop][locus] = label12count;
 	  //	  data->numalleles[pop][locus] = data->numind[pop][locus] * genomes;
 	  }
-	label1count = floor( (((double) label1count/label12count * data->numalleles[pop][locus]))+0.5 );
+	label1count = (long) floor( (((double) label1count/label12count * data->numalleles[pop][locus]))+0.5 );
 	for(ind=0;ind < label1count; ind++)
 	  {
 	    data->yy[pop][ind][locus][0][0] = label1;
@@ -1563,7 +1572,7 @@ read_hapmap (FILE * infile, data_fmt * data, option_fmt * options,  long pop)
 	    data->numind[pop][locus] = label12count / genomes;
 	  }
 	// data->numind[pop][locus] * genomes;
-	label1count = floor( (((double) label1count/label12count * data->numalleles[pop][locus]))+0.5 );
+	label1count = (long) floor( (((double) label1count/label12count * data->numalleles[pop][locus]))+0.5 );
 	for(ind=0;ind < label1count; ind++)
 	  {
 	    data->yy[pop][ind][locus][0][0] = label1;
@@ -2223,7 +2232,7 @@ void print_spectra(world_fmt * world, option_fmt * options,data_fmt * data)
 	  loctotal = 0;
 	  for(a=0; a < maxalleles[locus]; a++)
 	    {
-	      loctotal += freq[pop][locus][a];
+	      loctotal += (long) freq[pop][locus][a];
 	    }
 	  total[pop][locus] = loctotal;
 	  grandtotal[locus] += loctotal;
