@@ -9,22 +9,50 @@
  
  creates data structures,
  read data (Electrophoretic loci, sequences, microsats),
- feeds data into tree (?),
  prints data,
  destroys data.
  
  
- Theta(1)=4 N(1)mu, Theta(2)=4 N(2)mu,
- M(1) = m(1)/mu, and M(2)= m(2)/mu
+ Theta(i)=4 N(i)mu
+ M(ji) = m(ji)/mu
+ 4 N(i)m(ji) = Theta(i)M(ji)
                                                                                                                
- Peter Beerli 1996, Seattle
- beerli@fsu.edu
+/*-----------------------------------------------------------------
+  Bayesian and Maximum likelihood estimation of migration rates 
+  using coalescent trees
  
-Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
-Copyright 2003-2004 Peter Beerli, Tallahassee FL
+  Peter Beerli
+  Department of Scientific Computing
+  Florida State University
+  Tallahassee, FL 32306-4120
+  beerli@fsu.edu
  
-$Id: data.h 1593 2009-12-06 22:42:27Z beerli $
--------------------------------------------------------*/
+  
+Copyright 1997-2002 Peter Beerli and Joseph Felsenstein
+Copyright 2003-2008 Peter Beerli
+Copyright 2009-2012 Peter Beerli and Michal Palczewski
+
+Permission is hereby granted, free of charge, to any person obtaining a copy 
+of this software and associated documentation files (the "Software"), to deal 
+in the Software without restriction, including without limitation the rights 
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies 
+of the Software, and to permit persons to whom the Software is furnished to do 
+so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all copies 
+or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, 
+INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
+PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
+HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
+CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE 
+OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. 
+
+$Id: data.h 2067 2012-07-27 20:59:32Z beerli $
+ 
+*----------------------------------------------------------------
+*/
 
 #include "migration.h"
 
