@@ -2,29 +2,43 @@
 /*definitions.h*/
 #define MIGRATE_DEFINITION
 /*-----------------------------------------------------------------
-  Maximum likelihood estimation of migration rates 
+  Bayesian and Maximum likelihood estimation of migration rates 
   using coalescent trees
  
   Peter Beerli
-  School of Computational Science and Biological Sciences
+  Department of Scientific Computing
   Florida State University
   Tallahassee, FL 32306-4120
   beerli@fsu.edu
  
-  With help of Joe Felsenstein (joe@gs.washington.edu),
-  Mary Kuhner and Jon Yamato (mkkuhner@gs.washington.edu)
- 
   
-Copyright 2002 Peter Beerli and Joseph Felsenstein
+Copyright 1997-2002 Peter Beerli and Joseph Felsenstein
 Copyright 2003-2008 Peter Beerli
-Copyright 2009-2010 Peter Beerli and Michal Palczewski
+Copyright 2009-2012 Peter Beerli and Michal Palczewski
+
+Permission is hereby granted, free of charge, to any person obtaining a copy 
+of this software and associated documentation files (the "Software"), to deal 
+in the Software without restriction, including without limitation the rights 
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies 
+of the Software, and to permit persons to whom the Software is furnished to do 
+so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all copies 
+or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, 
+INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
+PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
+HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
+CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE 
+OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. 
+
+$Id: definitions.h 2067 2012-07-27 20:59:32Z beerli $
  
-$Id: definitions.h 2033 2012-05-11 15:21:41Z beerli $
- 
-  *----------------------------------------------------------------
-  */
+*----------------------------------------------------------------
+*/
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "3.2.19"
+#define MIGRATEVERSION "3.3.0"
 #endif
 #ifndef MIGRATESUBVERSION
 #define MIGRATESUBVERSION "x"
@@ -75,24 +89,23 @@ $Id: definitions.h 2033 2012-05-11 15:21:41Z beerli $
 #undef LCG
 #endif
 
-#ifdef __MWERKS__
-    #include "conf.h"
-    #undef HAVE_LGAMMA
-    #define HAVE_STRFTIME 1
-    #define HIGHBITS
-    #define LAMARC_MALLOC
-    #ifdef macintosh
-    #define MAC
-    #include <ansi_prefix.mac.h> /*fixes time problems */
-#else /*macintosh */
-    #define DOS
-    #undef HAVE_STRINGS_H
-    #undef HAVE_LGAMMA
-    #define HAVE_STRFTIME 1
-    #define HIGHBITS
-    #define LAMARC_MALLOC
-    #endif /*windows */
-#endif /*MWERKS*/
+#include "conf.h"
+#undef HAVE_LGAMMA
+#define HAVE_STRFTIME 1
+//#define HIGHBITS
+// #define LAMARC_MALLOC
+//#ifdef macintosh
+//    #define MAC
+//    #include <ansi_prefix.mac.h> /*fixes time problems */
+//#else /*macintosh */
+//    #define DOS
+//    #undef HAVE_STRINGS_H
+//    #undef HAVE_LGAMMA
+//    #define HAVE_STRFTIME 1
+//    #define HIGHBITS
+//    #define LAMARC_MALLOC
+//   #endif /*windows */
+//#endif /*MWERKS*/
 
 #ifdef WIN32
     #define DOS
@@ -488,9 +501,9 @@ long chains is used */
 #define STANDARD               1 /*adaptive heating scheme*/
 #define BOUNDED                2 /*bounded adaptive scheme*/
 /* maximization material*/
-#define SINGLELOCUS            0 /*+ */
-#define MULTILOCUS             1 /*+ */
-#define PROFILE                2 /*+ */
+#define SINGLELOCUS            0L /*+ */
+#define MULTILOCUS             1L /*+ */
+#define PROFILE                2L /*+ */
 /* print and plot material*/
 #define MULTILOCUSPLOT         (boolean) 1
 #define SINGLELOCUSPLOT		   (boolean) 0
@@ -508,9 +521,9 @@ long chains is used */
 #define PAGEFEEDWORLD               fprintf(world->outfile,"\n\f\n")
 #define PAGEFEEDW                   fprintf(universe[0]->outfile,"\n\f\n")
 #define LINELENGTH           90    /* number of print positions*/
-#define START                  0
-#define STOP                   1
-#define CONT                   3
+#define START                  0L
+#define STOP                   1L
+#define CONT                   3L
 /* tree-print options */
 #define _NONE                   0 /*+ */
 #define ALL                    1 /*+ */
