@@ -18,7 +18,7 @@
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
- $Id: mcmc1.c 2035 2012-05-16 20:03:33Z beerli $
+ $Id: mcmc1.c 2056 2012-06-14 02:38:30Z beerli $
  -------------------------------------------------------*/
 /* \file mcmc1.c
  
@@ -600,9 +600,9 @@ set_new_proposal (proposal_fmt ** proposal, timelist_fmt * tl, world_fmt * world
     (*proposal)->design0list = world->design0list;
     newsize = 4 * listsize;
     if((*proposal)->nodedata == NULL)
-        (*proposal)->nodedata = (node **) calloc (newsize, sizeof (node *));
+        (*proposal)->nodedata = (node **) mycalloc (newsize, sizeof (node *));
     else
-        (*proposal)->nodedata = (node **) realloc ((*proposal)->nodedata, newsize * sizeof (node *));
+        (*proposal)->nodedata = (node **) myrealloc ((*proposal)->nodedata, newsize * sizeof (node *));
     //xcode  oldsize = (*proposal)->listsize;
     memset((*proposal)->nodedata, 0, newsize * sizeof (node *));
     (*proposal)->aboveorigin = (*proposal)->nodedata;
@@ -672,7 +672,7 @@ jumblenodes (node ** s, long n)
     memcpy (temp, s, sizeof (node *) * n);
     for (i = 0; i < n && tn > 0; i++)
     {
-        s[i] = temp[rr = RANDINT (0, tn - 1)];
+        s[i] = temp[rr = RANDINT (0L, tn - 1)];
         temp[rr] = temp[tn - 1];
         tn--;
     }
@@ -775,9 +775,9 @@ chooseOrigin (proposal_fmt * proposal)
             tmp = goal[0];
             break;
         default:
-            tmp = goal[RANDINT (0, elem - 2)];
+            tmp = goal[RANDINT (0L, elem - 2)];
             while(tmp->back->type =='r')
-                tmp = goal[RANDINT (0, elem - 2)];
+                tmp = goal[RANDINT (0L, elem - 2)];
             break;
     }
     //032110 myfree(goal);
@@ -1226,7 +1226,7 @@ chooseTarget (proposal_fmt * proposal, timelist_fmt * timevector,
     if (*bordernum > 0)
     {
         // found elegible linages to coalesce to
-        proposal->target = bordernodes[RANDINT (0, (*bordernum) - 1)];
+        proposal->target = bordernodes[RANDINT (0L, (*bordernum) - 1)];
         if (proposal->target != rb)
         {
             proposal->tsister = showsister (proposal->target);
