@@ -16,7 +16,7 @@
  
   Copyright 2002 Peter Beerli and Joseph Felsenstein, Seattle WA
   Copyright 2003 Peter Beerli, Tallahassee FL
-  $Id: migration.h 2017 2012-03-19 22:38:48Z beerli $
+  $Id: migration.h 2053 2012-06-13 22:39:03Z beerli $
   *----------------------------------------------------------------
 */
 /**
@@ -272,7 +272,7 @@ typedef struct _data
     boolean hasghost;       //!< whether there is a population with no data or not \todo check if hasghost is still needed
   long ***shuffled;         //!< holds the random subset of individuals
   boolean oneliner;         //!< if a () is used in the sites lines it is assumed that all loci are on one line
-  long *datatype;
+  char *datatype;
   char *locitypes;          //!< holds all datatypes for each locus, options->datatype is the default
   char **locusname;
   long *subloci;            //!< holds the number of strictly linked "loci" that make up the locus for migrate
@@ -310,6 +310,8 @@ typedef struct _bayeshistogram
     MYREAL *medians;
     MYREAL *means;
     MYREAL *stds;
+    MYREAL **covariance; // holds the covariance structure per locus
+  long n; //holds the number of samples taken, this seem to be missing for the reading from mdimfile, but available otherwise
 } bayeshistogram_fmt;
 
 /// holds data for Bayesian approach
