@@ -16,7 +16,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: profile.c 1800 2011-01-29 13:40:00Z beerli $
+$Id: profile.c 1911 2011-06-03 19:08:55Z beerli $
  
 -------------------------------------------------------*/
 /*! \file profile.c
@@ -120,6 +120,80 @@ void calc_grid(FILE *alldim, world_fmt * world, MYREAL *testparam, MYREAL *ltest
 
 
 
+long choose_profile_parameters (world_fmt * world, long *profilelist)
+{
+    static boolean onetheta = FALSE;
+    static boolean onemig = FALSE;
+    long i, j;
+    long z=0;
+    long which;
+    for(which=0;which<world->numpop2;which++)
+      {
+        switch (world->options->custm2[which])
+	  {
+	  case 'C':
+	  case 'c':
+	  case '0':
+            break;
+        case 'M':
+        case 'm':
+            if (which < world->numpop && onetheta)
+	      continue;
+            if (which < world->numpop)
+	      {
+                profilelist[z++] = which;
+                onetheta = TRUE;
+	      }
+            if (which >= world->numpop && onemig)
+	      continue;
+            if (which >= world->numpop)
+            {
+                profilelist[z++] = which;
+                onemig = TRUE;
+            }
+            break;
+        case 'S': // Nm is symmetrical
+            j = (which - world->numpop) % (world->numpop - 1);
+            i = (which - world->numpop) / (world->numpop - 1);
+            if(world->options->usem)
+            {
+                profilelist[z++] = which;
+                continue;
+            }
+            else
+            {
+                if (i <= j)
+		  {
+		    profilelist[z++] = which;
+		    continue;
+		  }
+            }
+	    break;
+        case 's': // M is symmetric
+            j = (which - world->numpop) % (world->numpop - 1);
+            i = (which - world->numpop) / (world->numpop - 1);
+            if(!world->options->usem)
+            {
+	      profilelist[z++] = which;
+            }
+            else
+	      {
+                if (i <= j)
+		  {
+		    profilelist[z++] = which;
+                }
+            }     
+	    break;
+	  default:
+	    profilelist[z++] = which;
+	    break;
+	  }
+      }
+    if(world->options->gamma)
+      profilelist[z++]=world->numpop2;
+    return z;
+}
+
 boolean
 print_profile_likelihood_driver (long which, world_fmt * world, long *gmaxptr)
 {
@@ -580,12 +654,13 @@ void ascii_print_profile_table(char method, world_fmt *world)
   FILE *outfile = world->outfile;
 
   boolean failed = world->percentile_some_failed;
+  long thesize = WORDSIZE * world->numpop2;
 
-  thisparam = (char *) mycalloc(LINESIZE,sizeof(char));
+  thisparam = (char *) mycalloc(thesize ,sizeof(char));
   savedparam = thisparam;
   while(buffer[position] != '\0')
     {
-      strncpy(thisparam, buffer, LINESIZE-1);
+      strncpy(thisparam, buffer, thesize-1);
       strsep(&thisparam,"&"); // remove first element
       strsep(&thisparam,"&"); // remove second  element
       ptr = strsep(&thisparam,"&"); // keep third 
@@ -633,7 +708,7 @@ print_profile_percentile (world_fmt * world)
     long i, j, jj;
     boolean first = TRUE;
     boolean last = FALSE;
-    char fp[LINESIZE];
+    char fp[LONGLINESIZE];
     char **buffer = &world->buffer;
     long bufsize = 1;
     long failed=0;
@@ -780,7 +855,7 @@ sprint_percentile_header (char *outfile, boolean first)
 {
     const MYREAL probabilities[] = GRID2;
     long i;
-    char fp[LINESIZE];
+    char fp[LONGLINESIZE];
     if (first)
         sprintf (fp, "Parameter                          Lower percentiles\n");
     else
