@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: random.c 1983 2011-11-23 14:14:28Z beerli $
+$Id: random.c 2050 2012-06-08 20:46:46Z beerli $
 -------------------------------------------------------*/
 /* \file random.c */
 #include "sighandler.h"
@@ -537,6 +537,67 @@ void getseed_quasi (option_fmt *options)
 
 
 #ifdef MPI
+/// Random number seed function for MPI usage, the master generates numcpu random numbers
+/// and distributes them to the workers.
+void getseed(option_fmt *options)
+{
+  long test = -1;
+  long i;
+  long worker;
+  long *newseeds;
+  long newseed;
+  boolean found=FALSE;
+  MPI_Status status;
+  if (myID==MASTER)
+    {
+#ifdef MERSENNE_TWISTER
+      getseed_mt(options);
+#else
+      getseed_lcg(options);
+#endif
+      printf("%i> MASTER RANDOM NUMBER SEED:%li\n",myID,options->inseed);
+      newseeds = (long*) calloc(numcpu,sizeof(long));
+      for (worker=1;worker<numcpu;worker++)
+	{
+	  newseed = RANDINT(0,MAXLONG-1);
+	  for (i=1;i<worker;i++)
+	    {
+	      if (newseed == newseeds[i])
+		{
+		  found=TRUE;
+		  break;
+		}
+	    }
+	  if (found)
+	    worker--;
+	  else
+	    newseeds[worker] = newseed;
+	}
+      for (worker=1;worker<numcpu;worker++)
+	{
+	  newseed =  newseeds[worker];
+	  MYMPISEND(&newseed,(MYINT) ONE, MPI_LONG, (MYINT) worker, 0, comm_world);
+	}
+    }
+  else /*worker*/
+    {
+      MYMPIRECV (&options->inseed, (MYINT) ONE, MPI_LONG, MPI_ANY_SOURCE, MPI_ANY_TAG, comm_world, &status); 
+#ifdef MERSENNE_TWISTER
+      getseed_mt(options);
+#else
+      getseed_lcg(options);
+#endif
+#ifdef QUASIRANDOM
+      getseed_quasi(options);
+#endif
+#ifdef DEBUG
+      char nowstr[LINESIZE];
+      get_time (nowstr, "%c");
+      printf("%i> RANDOM NUMBER SEED:%li at time %s\n",myID,options->inseed,nowstr);
+#endif
+    }
+}
+#if 0 /*does not execute this section old getseed function*/
 /// Random number seed function for MPI usage, the main seed gets distributed to 
 /// all nodes and then the nodes pick a random number from the master seed for
 /// their own seed. given that the nodes typically analyze different loci
@@ -546,26 +607,42 @@ void getseed(option_fmt *options)
 {
   long test = -1;
   long i;
+  if (myID==MASTER)
+    {
 #ifdef MERSENNE_TWISTER
-  getseed_mt(options);
+      getseed_mt(options);
 #else
-  getseed_lcg(options);
+      getseed_lcg(options);
+#endif
+    }
+#ifdef DEBUG
+  char nowstr[LINESIZE];
+  get_time (nowstr, "%c");
+  printf("%i> random number seed broadcast start %s\n",myID, nowstr);
 #endif
   MYMPIBCAST (&options->inseed, 1, MPI_LONG, MASTER, comm_world);
-#ifdef DEBUG_MPI
-  printf("WARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNING\n");
-  printf("WARNING all random number seeds on the nodes are identical to the master     WARNING\n");
-  printf("WARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNING\n");
-  return;
+#ifdef DEBUG
+  get_time (nowstr, "%c");
+  printf("%i> random number seed broadcast finished %s\n",myID, nowstr);
 #endif
   if(myID != MASTER)
     {
-      for (i = 0; i <= myID; i++)
-	{
-	  test = RANDINT (1, MAXLONG-1); 
-	}
+      // sets all worker to same seed as master
+#ifdef MERSENNE_TWISTER
+      getseed_mt(options);
+#else
+      getseed_lcg(options);
+#endif
+#ifdef DEBUG_MPI
+      printf("WARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNING\n");
+      printf("WARNING all random number seeds on the nodes are identical to the master     WARNING\n");
+      printf("WARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNINGWARNING\n");
+      return;
+#endif
+      // gets a random value using the master seed
+      test = RANDINT (1, MAXLONG-1); 
       options->inseed = test;
-      //      printf("RANDOM NUMBER SEED: node=%i seed=%li\n",myID,test);
+      // reset the master seed to the own seed.
 #ifdef MERSENNE_TWISTER
       getseed_mt(options);
 #else
@@ -573,13 +650,19 @@ void getseed(option_fmt *options)
 #endif
 #ifdef QUASIRANDOM
       getseed_quasi(options);
+#endif
+#ifdef DEBUG
+      char nowstr[LINESIZE];
+      get_time (nowstr, "%c");
+      printf("%i> RANDOM NUMBER SEED:%li at time %s\n",myID,test,nowstr);
 #endif
     }
   else
     {
-      printf("MASTER RANDOM NUMBER SEED: node=%i seed=%li\n",myID,options->inseed);
+      printf("%i> MASTER RANDOM NUMBER SEED:%li\n",myID,options->inseed);
     }
 }
+#endif /*0*/
 #else
 void getseed(option_fmt *options)
 {
