@@ -20,7 +20,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c 2007 2012-02-19 18:16:49Z beerli $
+$Id: tools.c 2040 2012-05-31 19:32:14Z beerli $
 -------------------------------------------------------*/
 /* \file tools.c */
 
@@ -3535,6 +3535,28 @@ void print_stored_warnings(world_fmt *world)
 }
 
 
+// true should continue/shortcut loop
+// false should do the rest of the loop, and reset j0 to j
+// selects variable to work on, used on Bayesian context
+boolean shortcut(long j0,bayes_fmt *bayes, long *j)
+{
+  if(bayes->map[j0][1] == INVALID)
+    return TRUE;
+  else
+    {
+      *j = bayes->map[j0][1];
+    }
+  if(*j < j0)
+    {
+      return TRUE;
+    }
+  else
+    {
+      return FALSE;
+    }
+}
+
+
 // calculates a rough approximation to log(val)
 // max error = 0.0007
 // Submitted by Laurent de Soras, posted on 30 March 2001
