@@ -14,10 +14,14 @@
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2006 Peter Beerli, Tallahassee FL
  
-$Id: tools.h 1869 2011-05-06 12:08:40Z beerli $
+$Id: tools.h 2040 2012-05-31 19:32:14Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
+// selects variable to work on, used on Bayesian context
+// true should continue/shortcut loop
+// false should do the rest of the loop, and reset j0 to j
+extern boolean shortcut(long j0,bayes_fmt *bayes, long *j);
 
 extern MYREAL lengthof (node * p);
 extern MYINLINE node *crawlback (const node * theNode);
